@@ -1,7 +1,11 @@
 from __future__ import absolute_import
 
+import django
 from django.conf import settings
-from django.conf.urls.defaults import *
+if django.VERSION < (1, 3):
+    from django.conf.urls.defaults import *  # Django 1.2
+else:
+    from django.conf.urls import *
 from django.http import HttpResponse
 
 def handler500(request):
